<?php
/**
 * @file       divalign2/syntax/left.php
 * @brief      Enables center alignment for divalign2 plugin.
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @version    1.0
 * @author     Jason Byrne (original idea)
 * @author     Walter Torres (correction)
 * @author     Luis Machuca (implementation)
 */
 
// must be run within DokuWiki
if(!defined('DOKU_INC')) die();
 
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');
 
/**
 * All DokuWiki plugins to extend the parser/rendering mechanism
 * need to inherit from this class
 */
class syntax_plugin_divalign2_left extends DokuWiki_Syntax_Plugin {
 
    function getInfo(){
        return array(
            'author' => 'Luis Machuca B.',
            'email'  => 'luis.machuca@gulix.cl',
            'date'   => '2009-02-11',
            'name'   => 'divalign2',
            'desc'   => 'Add alignment (left) with #;; content #;;',
            'url'    => 'http://www.dokuwiki.org/plugin:divalign2',
        );
    }
 
    function getSort() { 
      return 157; 
    }
    function getType() { 
      return 'container'; 
    }
    function getAllowedTypes() { 
      return array( 
             'container', 'substition', 'protected', 
             'disabled', 'formatting', 'paragraphs'); 
    }
    
    function getPType() {
      return 'block';
    }
 
    function connectTo($mode) {
        $this->Lexer->addEntryPattern('#;;(?=.*#;;)',    
               $mode,'plugin_divalign2_left');
    }
    function postConnect() {
        $this->Lexer->addExitPattern('#;;','plugin_divalign2_left');
    }
 
    function handle($match, $state, $pos, &$handler){
        switch ( $state ) {
          case DOKU_LEXER_ENTER: {
            $align = 'left';
            break;
            }
          case DOKU_LEXER_UNMATCHED: {
            $handler->_addCall('cdata', array($match), $pos);
            break;          
            }
        }
        return array($align,$state,$pos);
    }
 
    function render($mode, &$renderer, $data) {
 
        if ($mode == 'xhtml'){
 
          list($align,$state,$pos) = $data;
          switch ($state) {
            case DOKU_LEXER_ENTER: {
              if ($align) { 
                $renderer->doc .= '<div class="divalign-'.$align.'">'; 
                }
              break;
              }
            case DOKU_LEXER_EXIT : {
              $renderer->doc .= '</div>';
              break;
              }
          } // end switch
          return true;
        } // end if ($mode == 'xhtml')
 
        return false;
    }
 
}
 
